@@ -5,11 +5,11 @@
 #' remote server operated by Ricardo that provides air quality data files as R
 #' data objects.
 #'
-#' This family of functions has been written to make it easy to import data
-#' from across several UK air quality networks. Ricardo have provided .RData
-#' files (R workspaces) of all individual sites and years, as well as up to
-#' date meta data. These files are updated on a daily basis. This approach
-#' requires a link to the Internet to work.
+#' This family of functions has been written to make it easy to import data from
+#' across several UK air quality networks. Ricardo have provided .RData files (R
+#' workspaces) of all individual sites and years, as well as up to date meta
+#' data. These files are updated on a daily basis. This approach requires a link
+#' to the Internet to work.
 #'
 #' For an up to date list of available sites that can be imported, see
 #' [importMeta()].
@@ -17,13 +17,13 @@
 #' The site codes and pollutant names can be upper or lower case.
 #'
 #' There are several advantages over the web portal approach where .csv files
-#' are downloaded. First, it is quick to select a range of sites, pollutants
-#' and periods (see examples below). Second, storing the data as .RData objects
-#' is very efficient as they are about four times smaller than .csv files ---
-#' which means the data downloads quickly and saves bandwidth. Third, the
-#' function completely avoids any need for data manipulation or setting time
-#' formats, time zones etc. The function also has the advantage that the proper
-#' site name is imported and used in \code{openair} functions.
+#' are downloaded. First, it is quick to select a range of sites, pollutants and
+#' periods (see examples below). Second, storing the data as .RData objects is
+#' very efficient as they are about four times smaller than .csv files --- which
+#' means the data downloads quickly and saves bandwidth. Third, the function
+#' completely avoids any need for data manipulation or setting time formats,
+#' time zones etc. The function also has the advantage that the proper site name
+#' is imported and used in \code{openair} functions.
 #'
 #' The data are imported by stacking sites on top of one another and will have
 #' field names \code{site}, \code{code} (the site code) and \code{pollutant}.
@@ -33,19 +33,25 @@
 #' \code{data_type}. Annual and monthly data provide whole network information
 #' including data capture statistics.
 #'
-#' All units are expressed in mass terms for gaseous species (ug/m3 for NO,
-#' NO2, NOx (as NO2), SO2 and hydrocarbons; and mg/m3 for CO). PM10
-#' concentrations are provided in gravimetric units of ug/m3 or scaled to be
-#' comparable with these units. Over the years a variety of instruments have
-#' been used to measure particulate matter and the technical issues of
-#' measuring PM10 are complex. In recent years the measurements rely on FDMS
-#' (Filter Dynamics Measurement System), which is able to measure the volatile
-#' component of PM. In cases where the FDMS system is in use there will be a
-#' separate volatile component recorded as 'v10' and non-volatile component
-#' 'nv10', which is already included in the absolute PM10 measurement. Prior to
-#' the use of FDMS the measurements used TEOM (Tapered Element Oscillating.
-#' Microbalance) and these concentrations have been multiplied by 1.3 to
-#' provide an estimate of the total mass including the volatile fraction.
+#' All units are expressed in mass terms for gaseous species (ug/m3 for NO, NO2,
+#' NOx (as NO2), SO2 and hydrocarbons; and mg/m3 for CO). PM10 concentrations
+#' are provided in gravimetric units of ug/m3 or scaled to be comparable with
+#' these units. Over the years a variety of instruments have been used to
+#' measure particulate matter and the technical issues of measuring PM10 are
+#' complex. In recent years the measurements rely on FDMS (Filter Dynamics
+#' Measurement System), which is able to measure the volatile component of PM.
+#' In cases where the FDMS system is in use there will be a separate volatile
+#' component recorded as 'v10' and non-volatile component 'nv10', which is
+#' already included in the absolute PM10 measurement. Prior to the use of FDMS
+#' the measurements used TEOM (Tapered Element Oscillating. Microbalance) and
+#' these concentrations have been multiplied by 1.3 to provide an estimate of
+#' the total mass including the volatile fraction.
+#'
+#' Some sites report hourly and daily PM10 and / or PM2.5. When \code{data_type
+#' = "daily"} and there are both hourly and 'proper' daily measurements
+#' available, these will be returned as e.g. "pm2.5" and "gr_pm2.5"; the former
+#' corresponding to data based on original hourly measurements and the latter
+#' corresponding to daily gravimetric measurements.
 #'
 #' The function returns modelled hourly values of wind speed (\code{ws}), wind
 #' direction (\code{wd}) and ambient temperature (\code{air_temp}) if available
@@ -56,12 +62,12 @@
 #' into the network throughout its history have been scaled by 1.3 if they have
 #' a heated inlet (to account for loss of volatile particles) and 0.83 if they
 #' do not have a heated inlet. The few TEOM instruments in the network after
-#' 2008 have been scaled using VCM (Volatile Correction Model) values to
-#' account for the loss of volatile particles. The object of all these scaling
-#' processes is to provide a reasonable degree of comparison between data sets
-#' and with the reference method and to produce a consistent data record over
-#' the operational period of the network, however there may be some
-#' discontinuity in the time series associated with instrument changes.
+#' 2008 have been scaled using VCM (Volatile Correction Model) values to account
+#' for the loss of volatile particles. The object of all these scaling processes
+#' is to provide a reasonable degree of comparison between data sets and with
+#' the reference method and to produce a consistent data record over the
+#' operational period of the network, however there may be some discontinuity in
+#' the time series associated with instrument changes.
 #'
 #' No corrections have been made to the PM2.5 data. The volatile component of
 #' FDMS PM2.5 (where available) is shown in the 'v2.5' column.
@@ -113,8 +119,8 @@
 #'   Defaults to `TRUE`.
 #'
 #' @export
-#' @return Returns a data frame of hourly mean values with date in POSIXct
-#'   class and time zone GMT.
+#' @return Returns a data frame of hourly mean values with date in POSIXct class
+#'   and time zone GMT.
 #' @author David Carslaw and Trevor Davies
 #' @family import functions
 #' @examples
@@ -285,7 +291,9 @@ readSummaryData <-
             "gr10",
             "gr10_capture",
             "gr2.5",
-            "gr2.5_capture"
+            "gr2.5_capture",
+            "gr_pm2.5",
+            "gr_pm10"
           )
         ))
     }
